@@ -114,9 +114,15 @@ impl ChangesComponent {
     fn index_add_remove(&mut self) -> bool {
         if let Some(i) = self.selection() {
             if self.is_working_dir {
-                let path = Path::new(i.path.as_str());
-
-                return sync::stage_add(CWD, path);
+                if let Some(status) = i.status {
+                    let path = Path::new(i.path.as_str());
+                    return match status {
+                        StatusItemType::Deleted => {
+                            sync::stage_addremoved(CWD, path)
+                        }
+                        _ => sync::stage_add(CWD, path),
+                    };
+                }
             } else {
                 let path = Path::new(i.path.as_str());
 
@@ -158,7 +164,7 @@ impl DrawableComponent for ChangesComponent {
                 },
             );
             if selected {
-                style = style.modifier(Modifier::BOLD); //.fg(Color::White);
+                style = style.modifier(Modifier::BOLD);
             }
 
             Text::Styled(Cow::from(txt), style)
@@ -231,7 +237,8 @@ impl Component for ChangesComponent {
                         }
                         true
                     }
-                    keys::STATUS_RESET_FILE => {
+                    keys::STATUS_RESET_FILE_1
+                    | keys::STATUS_RESET_FILE_2 => {
                         self.is_working_dir
                             && self.dispatch_reset_workdir()
                     }
