@@ -14,7 +14,7 @@ use tui::{
     backend::Backend,
     layout::{Alignment, Rect},
     style::{Color, Style},
-    widgets::{Block, Borders, Paragraph, Text, Widget},
+    widgets::{Block, Borders, Clear, Paragraph, Text},
     Frame,
 };
 
@@ -34,7 +34,9 @@ impl DrawableComponent for ResetComponent {
                 Style::default().fg(Color::Red),
             ));
 
-            ui::Clear::new(
+            let area = ui::centered_rect(30, 20, f.size());
+            f.render_widget(Clear, area);
+            f.render_widget(
                 Paragraph::new(txt.iter())
                     .block(
                         Block::default()
@@ -42,8 +44,8 @@ impl DrawableComponent for ResetComponent {
                             .borders(Borders::ALL),
                     )
                     .alignment(Alignment::Left),
-            )
-            .render(f, ui::centered_rect(30, 20, f.size()));
+                area,
+            );
         }
     }
 }
